<div align="center">
  <img src="docs/assets/covcheck-dino-banner.png">
  <h1>covcheck</h1>

  <p>
    <strong>Command-line tool for code coverage validation</strong>
  </p>
</div>

## About

`covcheck` is intended to be used in conjunction with [coverage.py](https://coverage.readthedocs.io/), which already has support for `pytest`, `unittest`, and `nosetest`. All you have to do is point `covcheck` to the `coverage.xml` file produced when running your tests.

For more information on how to use `covcheck` please check out the [official docs page](https://humeai.github.io/covcheck).
